@@ -6,7 +6,7 @@ use base qw( Rose::ObjectX::CAF );
 use Scalar::Util qw( blessed );
 use Search::Tools::MethodMaker;
 
-our $VERSION = '0.98';
+our $VERSION = '0.99';
 
 __PACKAGE__->mk_accessors(qw( debug ));
 
@@ -100,7 +100,8 @@ sub _normalize_args {
         )->parse($q);
     }
     elsif ( ref($q) eq 'ARRAY' ) {
-        warn "query ARRAY ref deprecated as of version 0.24";
+        carp "query ARRAY ref deprecated as of version 0.24";
+        require Search::Tools::QueryParser;
         $args{query} = Search::Tools::QueryParser->new(
             debug => $debug,
             map { $_ => delete $args{$_} }
